@@ -30,7 +30,8 @@ from threading import Lock
 from itertools import product
 from functools import reduce
 from datetime import datetime
-if __os.uname()[4][:3] != 'arm':
+import platform as __platform
+if 'arm' not in __platform.architecture():
     import git
 import re
 from pathlib import Path
